@@ -164,40 +164,6 @@ totem_gdk_window_set_waiting_cursor (GdkWindow *window)
 	gdk_flush ();
 }
 
-void
-totem_create_symlinks (const char *orig, const char *dest)
-{
-	GDir *dir;
-	const char *name;
-
-	dir = g_dir_open (orig, 0, NULL);
-	if (dir == NULL)
-		return;
-
-	if (g_file_test (dest, G_FILE_TEST_IS_DIR) == FALSE)
-		return;
-
-	name = g_dir_read_name (dir);
-	while (name != NULL)
-	{
-		char *orig_full, *dest_full;
-
-		orig_full = g_build_path (G_DIR_SEPARATOR_S, orig, name, NULL);
-		dest_full = g_build_path (G_DIR_SEPARATOR_S, dest, name, NULL);
-
-		/* We don't check the return value, that's normal,
-		 * we're very silent people */
-		symlink (orig_full, dest_full);
-
-		g_free (orig_full);
-		g_free (dest_full);
-
-		name = g_dir_read_name (dir);
-	}
-
-	g_dir_close (dir);
-}
-
 gboolean
 totem_display_is_local (void)
 {
@@ -247,10 +213,24 @@ totem_time_to_string (gint64 msecs)
 	if (hour > 0)
 	{
 		/* hour:minutes:seconds */
-		return g_strdup_printf ("%d:%02d:%02d", hour, min, sec);
+		/* Translators: This is a time format, like "9:05:02" for 9
+		 * hours, 5 minutes, and 2 seconds. You may change ":" to
+		 * the separator that your locale uses or use "%Id" instead
+		 * of "%d" if your locale uses localized digits. Do not
+		 * translate the "long time format|" part. Remove it from
+		 * the translation.
+		 */
+		return g_strdup_printf (Q_("long time format|%d:%02d:%02d"), hour, min, sec);
 	} else {
 		/* minutes:seconds */
-		return g_strdup_printf ("%d:%02d", min, sec);
+		/* Translators: This is a time format, like "5:02" for 5
+		 * minutes and 2 seconds. You may change ":" to the
+		 * separator that your locale uses or use "%Id" instead of
+		 * "%d" if your locale uses localized digits. Do not
+		 * translate the "short time format|" part. Remove it from
+		 * the translation.
+		 */
+		return g_strdup_printf (Q_("short time format|%d:%02d"), min, sec);
 	}
 
 	return NULL;
