@@ -61,6 +61,17 @@ typedef enum {
 	TOTEM_REMOTE_COMMAND_SHOW,
 	TOTEM_REMOTE_COMMAND_TOGGLE_CONTROLS,
 	TOTEM_REMOTE_COMMAND_SHOW_PLAYING,
+	TOTEM_REMOTE_COMMAND_UP,
+	TOTEM_REMOTE_COMMAND_DOWN,
+	TOTEM_REMOTE_COMMAND_LEFT,
+	TOTEM_REMOTE_COMMAND_RIGHT,
+	TOTEM_REMOTE_COMMAND_SELECT,
+	TOTEM_REMOTE_COMMAND_DVD_MENU,
+	TOTEM_REMOTE_COMMAND_ZOOM_UP,
+	TOTEM_REMOTE_COMMAND_ZOOM_DOWN,
+	TOTEM_REMOTE_COMMAND_EJECT,
+	TOTEM_REMOTE_COMMAND_PLAY_DVD,
+	TOTEM_REMOTE_COMMAND_MUTE
 } TotemRemoteCommand;
 
 #define SHOW_PLAYING_NO_TRACKS "NONE"
